#
# spec file for package cockpit-packages
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name: cockpit-packages
Version: 2
Release: 1.1
Summary: A cockpit module for (un)installing packages
License: LGPL-2.1-or-later

Source:         %{name}-%{version}.tar.xz
Source10:       package-lock.json
Source11:       node_modules.spec.inc
Source12:       node_modules.sums
%include %_sourcedir/node_modules.spec.inc
BuildArch: noarch
%if ! 0%{?suse_version}
ExclusiveArch: %{nodejs_arches} noarch
%endif
%if ! 0%{?rhel} || 0%{?rhel} >= 10
BuildRequires: nodejs >= 18
%endif
BuildRequires: make
%if 0%{?suse_version}
# Suse's package has a different name
BuildRequires: appstream-glib
%else
BuildRequires: libappstream-glib
%endif
BuildRequires: gettext
%if 0%{?rhel} && 0%{?rhel} <= 8
BuildRequires: libappstream-glib-devel
%endif
BuildRequires: local-npm-registry
BuildRequires: cockpit-devel >= 293

Requires: cockpit-bridge
Requires: PackageKit

%description
A cockpit module for (un)installing packages

%prep
%setup -q -n %{name}-%{version}
rm -rf node_modules
rm -f package-lock.json
local-npm-registry %{_sourcedir} install --include=dev --ignore-scripts

%build
mkdir -p pkg
cp -r %{_datadir}/cockpit/devel/lib pkg/lib
# Bug in how cockpit devel is built
sed -i 's/import glob from "glob"/import { glob } from "glob"/' pkg/lib/cockpit-po-plugin.js
NODE_ENV=production npm run build

%install
PREFIX=/usr DESTDIR=%{buildroot} make install

# drop source maps, they are large and just for debugging
find %{buildroot}%{_datadir}/cockpit/ -name '*.map' | xargs --no-run-if-empty rm --verbose

%check
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*

# this can't be meaningfully tested during package build; tests happen through
# FMF (see plans/all.fmf) during package gating

%files
%doc README.md
%license LICENSE dist/index.js.LEGAL.txt dist/index.css.LEGAL.txt
%{_datadir}/cockpit
%{_datadir}/metainfo/*

%changelog
* Thu Mar  6 2025 miika.alikirri@suse.com
- Update to version 2:
  * pkg: Release version 2
  * pkg: Add copyright to spec file
  * misc: Updated README
  * pkg: Remove unused spec file
  * src: Add translation to Uninstall word
  * src: Show loading indicator while searching packages
  * src: Require superuser to view the page
  * src: Make search more responsive
  * src: Show "Reinstall" button on already installed pacakges
  * pkg: Add packages spec file
* Thu Feb 20 2025 miika.alikirri@suse.com
- Update to version 1:
  * pkg: Add packages spec file
  * misc: Display app as Packages instead of Starter Kit
* Thu Feb 20 2025 Miika Alikirri <miika.alikirri@suse.com>
- Initial cockpit-packages package
